==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/extensions/beanManager/unmanaged/Builder.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.extensions.beanManager.unmanaged;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

@ApplicationScoped
public class Builder {

    public static boolean postConstructCalled = false;
    public static boolean preDestroyCalled = false;

    @Inject
    Hammer hammer;

    @Inject
    Nail nail;

    public void build() {
        hammer.use(nail);
    }

    @PostConstruct
    public void init() {
        postConstructCalled = true;
    }

    @PreDestroy
    public void destroy() {
        preDestroyCalled = true;
    }

    public static void reset() {
        postConstructCalled = false;
        preDestroyCalled = false;
    }
}

==> cdi-tck-3.0.3-dist.zip: org/jboss/cdi/tck/tests/extensions/beanManager/unmanaged/Builder.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.extensions.beanManager.unmanaged;

import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

@ApplicationScoped
public class Builder {

    public static boolean postConstructCalled = false;
    public static boolean preDestroyCalled = false;

    @Inject
    Hammer hammer;

    @Inject
    Nail nail;

    public void build() {
        hammer.use(nail);
    }

    @PostConstruct
    public void init() {
        postConstructCalled = true;
    }

    @PreDestroy
    public void destroy() {
        preDestroyCalled = true;
    }

    public static void reset() {
        postConstructCalled = false;
        preDestroyCalled = false;
    }
}
